/**
 * Hides elements within a container and shows a specified element that must be used to "unhide" them.
 */

(function ($) {

    function s360_autohide(initial) {
        $('[data-hider]').each(function () {
            var $container = $(this);
            var $hider = $($container.data('hider'));
            var $hiderContainer = $($container.data('hiderContainer'));
            if (!initial) {
                $hiderContainer.children().insertBefore($hider);
                $hiderContainer.html('');
            }
            var breakPoints = {
                xs: $container.data('hiderXs'),
                sm: $container.data('hiderSm'),
                md: $container.data('hiderMd'),
                lg: $container.data('hiderLg')
            };
            // get current viewport
            var viewport = $('#vp-indicator').find('> div:visible').data('vp');
            var maxItems = breakPoints[viewport];

            var $children = $container.children().not($hider).not($hiderContainer).not('script');

            if($children.length > maxItems) {
                // move overflow children to hidden container, show hider
                $children.each(function(idx, elem) {
                    // mind the -1 because the hider itself needs space as well
                   if(idx >= maxItems - 1) {
                       $(elem).appendTo($hiderContainer);
                   }
                });
                $hider.removeClass('hidden');
            } else {
                $hider.addClass('hidden');
            }
        });
    }


    // CALLS
    // ===============
    $(document).ready(function () {
        s360_autohide(true);
        var debounced = _.debounce(function () {
            s360_autohide(false);
        }, 16);
        $(window).resize(debounced);
    });
})(jQuery);
